@@ -87,10 +87,12 @@ $variables =& $gCms->variables;
 if( preg_match( '/Mozilla/', $_SERVER["HTTP_USER_AGENT"] ) )
 {
   $variables['content-type'] = 'text/xml';
+  cmsms()->set_variable('content-type','text/xml');
 }
 else 
 {
   $variables['content-type'] = 'application/rss+xml';
+  cmsms()->set_variable('content-type','application/rss+xml');
 }
 
 // temporary hack
